@@ -3,7 +3,6 @@ import os.path
 from pathlib import Path
 from datetime import datetime
 from tkinter import PhotoImage,Radiobutton,font
-from py import process
 from ttkbootstrap.toast import ToastNotification
 import ttkbootstrap as ttk
 from ttkbootstrap.constants import *
@@ -22,6 +21,7 @@ if __package__:
     from .blur import overlay_image
     from .tflite.classification import Classifier, RopClassifier, FlowerClassifier
     from ..gui import CollapsableFrame
+    from .emo import EmotionClassifier
 else:
     GUI_DIR = os.path.dirname (os.path.dirname(__file__)) + '/gui' 
     if GUI_DIR not in sys.path:
@@ -41,6 +41,7 @@ else:
     from blur import overlay_image
     from tflite.classification import Classifier, RopClassifier, FlowerClassifier
     from gui import CollapsableFrame
+    from emo import EmotionClassifier
 
 cap = cv2.VideoCapture(0)
 INTERVAL = 100 # ms
@@ -128,7 +129,7 @@ class MainApp(ttk.Frame):
         f = font.Font(size=20)
         btn = ttk.Button(
             master=container,
-            text = Emoji.get('CAMERA WITH FLASH'),
+            text = 'CAPTURE',# Emoji.get('CAMERA WITH FLASH'),
             padding=PADDING,
             command= self.capture_image
         )
@@ -138,7 +139,7 @@ class MainApp(ttk.Frame):
 
         btn = ttk.Button(
             master=container,
-            text=Emoji.get('open file folder'),
+            text='BROWSE',#Emoji.get('open file folder'),
             # image='folder',
             padding=PADDING,
             command= self.open_save_folder
@@ -171,17 +172,17 @@ class MainApp(ttk.Frame):
         
         btn = ttk.Button(
             master=container,
-            text=Emoji.get('LOWER LEFT PAINTBRUSH'),
+            text='THEME',#Emoji.get('LOWER LEFT PAINTBRUSH'),
             padding=PADDING,
             command = self.change_style
         )
         # btn['font'] = f
         # btn.pack(side=LEFT, fill=X, expand=YES)  
-        btn.grid(row=10, column=0, sticky=N+S+E+W) 
+        btn.grid(row=10, column=0, sticky=N+S+E+W)
 
         btn = ttk.Button(
             master=container,
-            text=Emoji.get('NEGATIVE SQUARED CROSS MARK'),
+            text='EXIT',#Emoji.get('NEGATIVE SQUARED CROSS MARK'),
             padding=PADDING,
             command = self.quit # destroy is not enough
         )
@@ -207,7 +208,9 @@ class MainApp(ttk.Frame):
         input_img = cap.read()[1]
 
         if self.task.get() == 'emotion':
-            input_img = emo.detect_emotion(input_img)
+            if 'emotion' not in self.__dict__ or self.emotion is None:
+                self.emotion = EmotionClassifier()
+            input_img = self.emotion.detect_emotion(input_img)
         elif self.task.get() == 'C1000': # image classification on 1000 classes. use pretrained model on ImageNet
             if 'c1000' not in self.__dict__ or self.c1000 is None:
                 self.c1000 = Classifier()
