@@ -6,6 +6,7 @@ from ttkbootstrap.dialogs import Messagebox
 from ttkbootstrap.toast import ToastNotification
 import os
 import sys
+import uuid
 
 if __package__:
     from ..gui import file_search_frame
@@ -110,16 +111,16 @@ class DeviceInfoFrame(ttk.Frame):
             text='Trial Version, 28 days left',
             anchor=CENTER
         )
-        lic_title.pack(fill=X, pady=(0, 20))
+        # lic_title.pack(fill=X, pady=(0, 20))
 
         lbl = ttk.Label(
             master=lic_info,
             text='serial number:',
             anchor=CENTER,
-            font='Helvetica 8'
+            font='Helvetica 10'
         )
         lbl.pack(fill=X)
-        self.setvar('license', 'dtMM2-XYZGHIJKLMN3')
+        self.setvar('license', str(uuid.getnode()))
 
         lic_num = ttk.Label(
             master=lic_info,
