@@ -400,15 +400,14 @@ class FileSearchFrame(ttk.Frame):
 
         WaitingFrame.threadqueue.task_done()
         
-        if True: # self.master.attributes('-fullscreen'):
+        if sys.platform == 'win32': # in linux, toast in sub thread is buggy
             toast = ToastNotification(
                 title=title,
                 message=message, 
                 duration=2000,
             )
             toast.show_toast()
-        else:
-            Messagebox.show_info(message, title) # cannot do this in a sub thread
+            # Messagebox.show_info(message, title) # cannot do this in a sub thread
 
     def on_browse(self):
         """Callback for directory browse"""
