@@ -4,12 +4,11 @@ import sys
 import os.path
 if sys.platform == 'win32':
     sys.path.append(os.path.dirname(__file__))
-    from simulator import SMBus
+    from simulator import SMBus, PCF8574
 else:
     from smbus import SMBus
-
-# pip install pcf8574
-from pcf8574 import PCF8574
+	# pip install pcf8574
+    from pcf8574 import PCF8574
 
 
 I2C_LCD = 0x27
