@@ -1,4 +1,5 @@
 import os
+import sys
 import time
 from datetime import datetime
 from pathlib import Path
@@ -7,7 +8,6 @@ from PIL import Image, ImageTk, ImageDraw,ImageFont
 from threading import *
 
 import ttkbootstrap as ttk
-from ttkbootstrap.style import Bootstyle
 from tkinter.filedialog import askdirectory
 from ttkbootstrap.dialogs import Messagebox
 from ttkbootstrap.constants import *
@@ -29,6 +29,7 @@ if __package__:
     from .setting_frame import SettingFrame
     from . import LCD1602 as lcd
     from .liquidcrystal_i2c import LiquidCrystal_I2C
+    from ..gui import CollapsableFrame
 else:
     import led, acc, servo, joystick
     import passive_buzzer as pbz
@@ -37,10 +38,13 @@ else:
     from setting_frame import SettingFrame
     import LCD1602 as lcd
     from liquidcrystal_i2c import LiquidCrystal_I2C
-# import sys
-# sys.path.insert(0, './vehicle')
-# import vehicle.Adafruit_PWM_Servo_Driver as servo_drv
 
+    GUI_DIR = os.path.dirname (os.path.dirname(__file__))
+    if GUI_DIR not in sys.path:
+        sys.path.append(GUI_DIR)
+    print(GUI_DIR)
+
+    from gui import CollapsableFrame
 
 CAMERA_ID = 0
 cap = cv2.VideoCapture(CAMERA_ID)
@@ -166,7 +170,7 @@ class MainGui(ttk.Frame):
         left_panel = ttk.Frame(self, style='bg.TFrame')
         left_panel.pack(side=LEFT, fill=Y)
 
-        bus_cf = CollapsingFrame(left_panel)
+        bus_cf = CollapsableFrame(left_panel)
         bus_cf.pack(fill=X, pady=1)
 
         ## container
@@ -245,7 +249,7 @@ class MainGui(ttk.Frame):
 
         ################## VEHICLE ######################
 
-        v_cf = CollapsingFrame(left_panel)
+        v_cf = CollapsableFrame(left_panel)
         v_cf.pack(fill=X, pady=1)
 
         ## container
@@ -345,7 +349,7 @@ class MainGui(ttk.Frame):
 
         ################## RA ######################
 
-        v_cf = CollapsingFrame(left_panel)
+        v_cf = CollapsableFrame(left_panel)
         v_cf.pack(fill=X, pady=1)
 
         ## container
@@ -441,7 +445,7 @@ class MainGui(ttk.Frame):
 
         ############## STATUS Panel ################
         # status (collapsible)
-        status_cf = CollapsingFrame(left_panel)
+        status_cf = CollapsableFrame(left_panel)
         status_cf.pack(fill=BOTH, pady=1)
 
         ## container
@@ -575,7 +579,7 @@ class MainGui(ttk.Frame):
         ttk.Style().configure('Treeview', rowheight = TREEVIEW_ROW_HEIGHT, font=('', round(TREEVIEW_ROW_HEIGHT * 0.5)))
 
         ## scrolling text output
-        scroll_cf = CollapsingFrame(right_panel)
+        scroll_cf = CollapsableFrame(right_panel)
         scroll_cf.pack(fill=BOTH, expand=YES)
 
 
@@ -836,10 +840,13 @@ servo channels:
 
             s = self.measure_distance(flags=[1,0,0,0]) # update distances
             draw = ImageDraw.Draw(img)
-            ft = ImageFont.truetype('FreeMono.ttf', 25)
+            if sys.platform == 'win32':
+                ff = os.path.dirname(__file__) + '/FreeMonoBold.ttf'
+            else:
+                ff = 'FreeMono.ttf'
             draw.text((10, 10), 
             s, 
-            font = ft,
+            font = ImageFont.truetype(ff, 25),
             fill =(255, 255, 255))
             # draw.text((10, 10), "Distances : " + str(round(distance,1)), font=ft, fill =(255, 255, 255))
 
@@ -873,87 +880,6 @@ servo channels:
         else:
             self.liveview_size = LIVEVIEW_SIZE # (240,180)
 
-class CollapsingFrame(ttk.Frame):
-    """A collapsible frame widget that opens and closes with a click."""
-
-    def __init__(self, master, **kwargs):
-        super().__init__(master, **kwargs)
-        self.columnconfigure(0, weight=1)
-        self.cumulative_rows = 0
-
-        # widget images
-        self.images = [
-            ttk.PhotoImage(file=PATH/'icons8_double_up_24px.png'),
-            ttk.PhotoImage(file=PATH/'icons8_double_right_24px.png')
-        ]
-
-    def add(self, child, title="", bootstyle=PRIMARY, **kwargs):
-        """Add a child to the collapsible frame
-
-        Parameters:
-
-            child (Frame):
-                The child frame to add to the widget.
-
-            title (str):
-                The title appearing on the collapsible section header.
-
-            bootstyle (str):
-                The style to apply to the collapsible section header.
-
-            **kwargs (Dict):
-                Other optional keyword arguments.
-        """
-        if child.winfo_class() != 'TFrame':
-            return
-        
-        style_color = Bootstyle.ttkstyle_widget_color(bootstyle)
-        frm = ttk.Frame(self, bootstyle=style_color)
-        frm.grid(row=self.cumulative_rows, column=0, sticky=EW)
-
-        # header title
-        header = ttk.Label(
-            master=frm,
-            text=title,
-            bootstyle=(style_color, INVERSE)
-        )
-        if kwargs.get('textvariable'):
-            header.configure(textvariable=kwargs.get('textvariable'))
-        header.pack(side=LEFT, fill=BOTH, padx=10)
-
-        # header toggle button
-        def _func(c=child): return self._toggle_open_close(c)
-        btn = ttk.Button(
-            master=frm,
-            image=self.images[0],
-            bootstyle=style_color,
-            command=_func
-        )
-        btn.pack(side=RIGHT)
-
-        # assign toggle button to child so that it can be toggled
-        child.btn = btn
-        child.grid(row=self.cumulative_rows + 1, column=0, sticky=NSEW)
-
-        # increment the row assignment
-        self.cumulative_rows += 2
-
-    def _toggle_open_close(self, child):
-        """Open or close the section and change the toggle button 
-        image accordingly.
-
-        Parameters:
-            
-            child (Frame):
-                The child element to add or remove from grid manager.
-        """
-        if child.winfo_viewable():
-            child.grid_remove()
-            child.btn.configure(image=self.images[1])
-        else:
-            child.grid()
-            child.btn.configure(image=self.images[0])
-
 if __name__ == '__main__':
     
     # splash_root = ttk.Window()
